==> SimplyDualWielding-5.4.0%2B1.21.%286%2B%29-Fabric-sources.jar: eva/dualwielding/mixin/ServerGamePacketListenerImplMixin.java <==
package eva.dualwielding.mixin;

import eva.dualwielding.access.ServerPlayerGameModeAccess;
import eva.dualwielding.access.ServerboundPlayerActionPacketAccess;
import net.minecraft.class_2846;
import net.minecraft.class_3222;
import net.minecraft.class_3244;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.Shadow;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfo;

@Mixin(class_3244.class)
public class ServerGamePacketListenerImplMixin {

    @Shadow
    public class_3222 player;

    @Inject(
            method = "handlePlayerAction",
            at = @At(
                    value = "INVOKE",
                    target = "Lnet/minecraft/server/level/ServerPlayerGameMode;handleBlockBreakAction(Lnet/minecraft/core/BlockPos;Lnet/minecraft/network/protocol/game/ServerboundPlayerActionPacket$Action;Lnet/minecraft/core/Direction;II)V"
            ),
            cancellable = true
    )
    private void handlePlayerAction(class_2846 packet, CallbackInfo ci) {
        if (((ServerboundPlayerActionPacketAccess) packet).getOffhanded()) {
            ((ServerPlayerGameModeAccess) this.player.field_13974).dualWielding$handleBlockBreakingAction(
                    packet.method_12362(),
                    packet.method_12363(),
                    packet.method_12360(),
                    this.player.method_51469().method_31600(),
                    packet.method_42079());
        }
    }
}

==> SimplyDualWielding-6.0.5%2B1.21.%286%2B%29-Fabric-sources.jar: eva/dualwielding/mixin/ServerGamePacketListenerImplMixin.java <==
package eva.dualwielding.mixin;

import eva.dualwielding.access.ServerPlayerGameModeAccess;
import eva.dualwielding.access.ServerboundPlayerActionPacketAccess;
import net.minecraft.class_2846;
import net.minecraft.class_3222;
import net.minecraft.class_3244;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.Shadow;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfo;

@Mixin(class_3244.class)
public class ServerGamePacketListenerImplMixin {

    @Shadow
    public class_3222 player;

    @Inject(
            method = "handlePlayerAction",
            at = @At(
                    value = "INVOKE",
                    target = "Lnet/minecraft/server/level/ServerPlayerGameMode;handleBlockBreakAction(Lnet/minecraft/core/BlockPos;Lnet/minecraft/network/protocol/game/ServerboundPlayerActionPacket$Action;Lnet/minecraft/core/Direction;II)V"
            ),
            cancellable = true
    )
    private void handlePlayerAction(class_2846 packet, CallbackInfo ci) {
        if (((ServerboundPlayerActionPacketAccess) packet).getOffhanded()) {
            ((ServerPlayerGameModeAccess) this.player.field_13974).dualWielding$handleBlockBreakingAction(
                    packet.method_12362(),
                    packet.method_12363(),
                    packet.method_12360(),
                    this.player.method_51469().method_31600(),
                    packet.method_42079()
            );
            ((class_3244)(Object) this).method_41255(packet.method_42079());
            ci.cancel();
        }
    }
}
